? writability-225880-26.patch
? writability-225880-27.patch
? writability-225880-28.patch
? writability-225880-32.patch
Index: INSTALL.txt
===================================================================
RCS file: /cvs/drupal/drupal/INSTALL.txt,v
retrieving revision 1.68
diff -u -p -r1.68 INSTALL.txt
--- INSTALL.txt 7 May 2008 20:05:58 -0000 1.68
+++ INSTALL.txt 24 Jun 2008 15:47:35 -0000
@@ -73,15 +73,23 @@ INSTALLATION
http://drupal.org/project/translations and download the package. Extract
the contents to the same directory where you extracted Drupal into.
-2. GRANT WRITE PERMISSIONS ON CONFIGURATION FILE
+2. CREATE THE CONFIGURATION FILE AND GRANT WRITE PERMISSIONS
Drupal comes with a default.settings.php file in the sites/default
- directory. The installer will create a copy of this file filled with
- the details you provide through the install process, in the same
- directory. Give the web server write privileges to the sites/default
- directory with the command (from the installation directory):
+ directory. The installer uses this file as a template to create your
+ settings file using the details you provide through the install process.
+ To avoid problems when upgrading, Drupal is not packaged with an actual
+ settings file. You must create a file named settings.php. You may do so
+ by making a copy of default.settings.php (or create an empty file with
+ this name in the same directory). For example, (from the installation
+ directory) make a copy of the default.settings.php file with the command:
- chmod o+w sites/default
+ cp sites/default/default.settings.php sites/default/settings.php
+
+ Next, give the web server write privileges to the sites/default/settings.php
+ file with the command (from the installation directory):
+
+ chmod o+w sites/default/settings.php
3. CREATE THE DRUPAL DATABASE
@@ -116,11 +124,17 @@ INSTALLATION
mkdir sites/default/files
chmod o+w sites/default/files
- The install script will attempt to write-protect the sites/default
- directory after creating the settings.php file. If you make manual
- changes to that file later, be sure to protect it again after making
- your modifications. Failure to remove write permissions to that file
- is a security risk. Although the default location for the settings.php
+ The install script will attempt to write-protect the settings.php file and
+ the sites/default directory after saving your configuration. However, you
+ may need to manually write-protect them using the commands (from the
+ installation directory):
+
+ chmod a-w sites/default/settings.php
+ chmod a-w sites/default
+
+ If you make manual changes to the file later, be sure to protect it again
+ after making your modifications. Failure to remove write permissions to that
+ file is a security risk. Although the default location for the settings.php
file is at sites/default/settings.php, it may be in another location
if you use the multi-site setup, as explained below.
Index: sites/default/default.settings.php
===================================================================
RCS file: /cvs/drupal/drupal/sites/default/default.settings.php,v
retrieving revision 1.10
diff -u -p -r1.10 default.settings.php
--- sites/default/default.settings.php 8 Apr 2008 22:50:55 -0000 1.10
+++ sites/default/default.settings.php 24 Jun 2008 15:47:36 -0000
@@ -90,7 +90,7 @@
* $db_url = 'mysqli://username:password@localhost/databasename';
* $db_url = 'pgsql://username:password@localhost/databasename';
*/
-$db_url = 'mysql://username:password@localhost/databasename';
+$db_url = '';
$db_prefix = '';
/**
Index: install.php
===================================================================
RCS file: /cvs/drupal/drupal/install.php,v
retrieving revision 1.119
diff -u -p -r1.119 install.php
--- install.php 26 May 2008 17:12:54 -0000 1.119
+++ install.php 24 Jun 2008 15:47:36 -0000
@@ -874,19 +874,19 @@ function install_check_requirements($pro
$file = $conf_path;
// Verify that the directory exists.
if (drupal_verify_install_file($conf_path, FILE_EXIST, 'dir')) {
- // Check to see if a settings.php already exists.
+ // Check to make sure a settings.php already exists.
+ $file = $settings_file;
+ $exists = FALSE;
if (drupal_verify_install_file($settings_file, FILE_EXIST)) {
+ $exists = TRUE;
// If it does, make sure it is writable.
$writable = drupal_verify_install_file($settings_file, FILE_READABLE|FILE_WRITABLE);
- $file = $settings_file;
- }
- else {
- // If not, make sure the directory is.
- $writable = drupal_verify_install_file($conf_path, FILE_READABLE|FILE_WRITABLE, 'dir');
}
}
-
- if (!$writable) {
+ if (!$exists) {
+ drupal_set_message(st('The @drupal installer requires that you create %file as part of the installation process, and then make it writable. If you are unsure how to grant file permissions, please consult the on-line handbook.', array('@drupal' => drupal_install_profile_name(), '%file' => $file, '@handbook_url' => 'http://drupal.org/server-permissions')), 'error');
+ }
+ elseif (!$writable) {
drupal_set_message(st('The @drupal installer requires write permissions to %file during the installation process. If you are unsure how to grant file permissions, please consult the on-line handbook.', array('@drupal' => drupal_install_profile_name(), '%file' => $file, '@handbook_url' => 'http://drupal.org/server-permissions')), 'error');
}
}